﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityStandardAssets.Characters.FirstPerson;
using UnityEngine.SceneManagement;

public class PlayerHUDController : MonoBehaviour {
	private RigidbodyFirstPersonController PlayerController;
	private bool _levelComplete;

	private float StartTime;
	public RectTransform ChargeMeter;
	public Image ChargeMeterImage;
	private float MeterMaxWidth;
	private float MeterHeight;
	private float TimeCompleted;

	private int _wallCount;
	public int WallCount{
		get { return _wallCount; }
		protected set {
			_wallCount = value;
			if(value == 0){
				OnDestroyLastWall();
			} else {
				WallsLeft.text = string.Format("{0} wall{1} left!", _wallCount, _wallCount > 1 ? "s" : "");
			}
		}
	}

	public Text WallsLeft;
	public Text TotalTimer;
	public Text Timer;
	public Text NewRecord;
	public Text CurrentBestTime;
	public Text TimeToBeat;

	private static PlayerHUDController instance;
	public static void DestroyWall(){
		instance.WallCount = instance.WallCount - 1;
	}

	void Awake(){
		instance = this;
		StartTime = Time.time;
		NewRecord.enabled = false;
		TotalTimer.enabled = false;
		TimeToBeat.enabled = false;
		CurrentBestTime.enabled = false;
		Vector2 MeterSize = ChargeMeter.sizeDelta;
		MeterMaxWidth = MeterSize.x;
		MeterHeight = MeterSize.y;
		_levelComplete = false;
	}


	// Use this for initialization
	void Start () {
		GameObject Player = GameObject.Find("Player");
		GameObject BreakableWalls = GameObject.Find("Breakable Walls");
		WallCount = BreakableWalls.transform.childCount;

		PlayerController = Player.GetComponent<RigidbodyFirstPersonController>();
	}
	
	// Update is called once per frame
	void Update () {
		float ChargeInterval = PlayerController.ChargeLevel / PlayerController.movementSettings.TimeToChargeSurge;

		float MeterWidth = Mathf.Lerp(0, MeterMaxWidth, ChargeInterval);
		Vector3 MeterSize = new Vector3(MeterWidth, MeterHeight, 1);
		ChargeMeter.sizeDelta = MeterSize;
		Color c = ChargeMeterImage.color;
		c.a = Mathf.Lerp(0, 1f, ChargeInterval);
		ChargeMeterImage.color = c;

		float TimeElapsed = Time.time - StartTime;
		if(_levelComplete){
			TimeElapsed = TimeCompleted;
		}
 		Timer.text = GetFormattedTime(TimeElapsed);
	}

	public static string GetFormattedTime(float t){
		string ret;
		TimeSpan ts = TimeSpan.FromSeconds(t);

		ret = string.Format("{0:D2}:{1:D2}:{2:D2}", Mathf.Clamp(ts.Minutes, 0, 99), ts.Seconds, ts.Milliseconds / 10);
		return ret;
	}

	void OnDestroyLastWall(){
		WallsLeft.text = "Finished!";
		TimeCompleted = Time.time - StartTime;
		_levelComplete = true;

		float BestTime = GameManager.GetBestTimeForLevel(SceneManager.GetActiveScene().name);
		if(TimeCompleted < BestTime){
			NewRecord.enabled = true;
			Timer.color = new Color(1.0f, 1.0f, 0.5f, 1.0f);
		} else {
			TimeToBeat.enabled = true;
			CurrentBestTime.enabled = true;
			string SceneName = SceneManager.GetActiveScene().name;
			CurrentBestTime.text = GetFormattedTime(GameManager.GetBestTimeForLevel(SceneName));
		}

		TotalTimer.text = GetFormattedTime(GameManager.GetTotalTime() + TimeCompleted);
		TotalTimer.enabled = true;

		Invoke("FinishLevel", 5.0f);
	}

	void FinishLevel(){
		GameManager.CompleteLevel(SceneManager.GetActiveScene().name, TimeCompleted);
	}
}
