﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityStandardAssets.Characters.FirstPerson;

public class BreakableWall : MonoBehaviour {
	public float Health = 100f;
	public GameObject Debris;
	public GameObject Sheetrock;
	RigidbodyFirstPersonController playerController;
	BattleCry playerBattleCry;
	ParticleSystem particleSystem;
	AudioSource audio;

	// Use this for initialization
	void Start () {
		GameObject player = GameObject.Find("Player");
		playerController = player.GetComponent<RigidbodyFirstPersonController>();
		playerBattleCry = player.GetComponent<BattleCry>();
		particleSystem = player.GetComponentInChildren<ParticleSystem>();
		audio = GetComponent<AudioSource>();
	}

	void OnCollisionEnter(Collision collision){
		if(collision.gameObject.tag == "Player" && playerController.Charging){
			playerController.Shake = 0.175f;
			playerController.ChargeLevel *= 0.25f;
			playerBattleCry.RandomBattleCry();
			Explode(collision.gameObject.transform.position, collision.relativeVelocity);
		}
	}

	void Explode(Vector3 explosionOrigin, Vector3 explosionDirection){
		int rowIndex, colIndex;
		int debrisRows = Mathf.FloorToInt(Sheetrock.transform.localScale.y);
		int debrisCols = Mathf.FloorToInt(Sheetrock.transform.localScale.z);

		debrisRows = Mathf.FloorToInt(debrisRows * transform.localScale.y);
		debrisCols = Mathf.FloorToInt(debrisCols * transform.localScale.z);

		particleSystem.Play();
		PlayerHUDController.DestroyWall();

		for(rowIndex=0; rowIndex<debrisRows; rowIndex++){
		for(colIndex=0; colIndex<debrisCols; colIndex++){
			GameObject debris;
			Rigidbody debrisBody;
			float debrisY = 0.5f + rowIndex;
			float debrisZ = 0.5f + colIndex - (debrisCols*0.5f);
			Vector3 debrisPosition = new Vector3(0, debrisY, debrisZ);

			debris = Instantiate(Debris, transform.position + debrisPosition, Quaternion.identity);
			debris.transform.parent = transform.parent;

			debrisBody = debris.GetComponent<Rigidbody>();
			debrisBody.AddExplosionForce(100.0f, explosionOrigin, 10.0f, 2.0f);
			debrisBody.AddForce(explosionDirection * 0.0625f, ForceMode.Impulse);
			debrisBody.AddRelativeTorque(Random.insideUnitSphere, ForceMode.Impulse);
		}}

		GetComponent<Collider>().enabled = false;

		audio.Play();
		for(int i=0; i<transform.childCount; i++){
			Destroy(transform.GetChild(i).gameObject);
		}
		Destroy(gameObject, audio.clip.length);
	}
}
